@@ -1,6 +1,4 @@
-# Test the PlotCor and PlotWeight functions #
-
-# Test that PlotCor creates a ggplot object #
+# Test the PlotCor function #
 test_that("plotcor produces a graph", {
   
   data(Mass, envir = environment())
@@ -8,12 +6,13 @@ test_that("plotcor produces a graph", {
   
   cross <- crosswin(xvar = list(Temp = MassClimate$Temp), 
                     xvar2 = list(Rain = MassClimate$Rain), cdate = MassClimate$Date,
-                    bdate = Mass$Date, furthest = 2, closest = 1, 
-                    stat = "max", stat2 = "max", type = "variable",
+                    bdate = Mass$Date, range = c(2, 1), 
+                    stat = "max", stat2 = "max", type = "relative",
                     cmissing = FALSE, cinterval = "day")
   
   test <- plotcor(cor.output = cross, type = "A")
   
+  # Test plotcor produces a ggplot object
   expect_true(attr(test, "class")[1]=="gg") 
   
 })
\ No newline at end of file
